Redis-Py — IoC 0.0.15 documentation

### Navigation

- index
- next |
- previous |
- IoC 0.0.15 documentation »
- Extra »

# Redis-Py

Redis-Py is an interface to the Redis key-value store.

## Configuration

    ioc.extra.redis:
        clients:
            default:
                connection: default

        connections:
            default:
                host:               'localhost'
                port:               6379
                db:                 0
                password:
                socket_timeout:
                encoding:           'utf-8'
                encoding_errors:    'strict'
                decode_responses:   false

## Services available

- ioc.extra.redis.manager: the Redis manager to retrieve client and connection
- ioc.extra.redis.connection.default: the `default` connection
- ioc.extra.redis.client.default: the `default` client

### Navigation

- index
- next |
- previous |
- IoC 0.0.15 documentation »
- Extra »